# General section defines properties of the thememanger
[general]
# SVG file to load (path relative to this file) which contains all SVG items
svgfile=gray_reflection.svgz
# Game aspect ratio
aspect-ratio=1.60
# Color name for player 0.
colorNamePlayer0=Black
# Color name for player 1.
colorNamePlayer1=Red

# The 'intro display' (display for intro screen)
[introdisplay]
# SVG ID of background grafix
background-svgid=background
# Static decoration sprites, always displayed
decoration=
# Position of the game board for the pieces [0..1]
board-pos=0.445,0.15
# Spread pieces on board [0..1]
board-spread=0.0588,0.0588
# Speed in [rel/ms]
move-velocity=0.4

# Position and spread of the pieces above the board
piece0-pos=0.4400,0.0300
piece1-pos=0.4400,0.1000
piece-spread=0.0095



# The 'game display' itself
[gamedisplay]
# SVG ID of background grafix
background-svgid=background
# Static decoration sprites, always displayed
decoration=boardback
# Position of the game board for the pieces [0..1]
board-pos=0.141,0.145
# Spread of sprites for board columns [0..1]
board-spread=0.059,0.059
# Movebar arrow position (must be same than movebar pos) [0..1]
arrow-pos=0.12,0.04
# Velocity [relativ/second] for game piece move animation
move-velocity=0.8
# Show reflections
use-reflection=true



# A game piece used in the intro screen
[intro_piece]
# 'pos' is set by program!
# Width of the item [0..1]
width=0.06
# SVG ID of the image: Auto means to read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=1
# SVG ID for frame0
frame0=piece0
# SVG ID for frame1
frame1=piece1



# A game piece used in the game screen 
[piece]
# 'pos' set by program!
# Center the graphics around its position
center=true
# Z-Value 
zValue=10.0
# Width of the item [0..1]
width=0.0500
# SVG ID of the image: Auto means to read read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=1
# SVG ID for frame0
frame0=piece0
# SVG ID for frame1
frame1=piece1



# A HINT piece used in the game screen
[hint]
# 'pos' set by program!
# Center the graphics around its position
center=true
# Z-Value 
zValue=10.0
# Width of the item [0..1]
width=0.0500
# SVG ID of the image
svgid=hint



# Arrow to indicate the column which was played
[arrow]
# 'pos' set by program!
# Width of the item [0..1]
width=0.045
# Z-Value 
zValue=250.0
# SVG ID of the image: Auto means to read read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=2
# SVG ID for frame0
frame0=arrow
# SVG ID for frame1
frame1=arrow0
# SVG ID for frame2
frame2=arrow1



# A star to indicate the winning pieces
[star]
# 'pos' set by program!
# Z-Value 
zValue=200.0
# Width of the item [0..1]
width=0.045
# Center the graphics around its position
center=true
# SVG ID of the image: Auto means to read read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=7
# Scale pixmaps with reference to this frame (which get sized to 'width')
ref-frame=star4
# SVG ID for frame0
frame0=star0
# SVG ID for frame1
frame1=star1
# SVG ID for frame2
frame2=star2
# SVG ID for frame3
frame3=star3
# SVG ID for frame4
frame4=star4
# SVG ID for frame5
frame5=star5
# SVG ID for frame6
frame6=star6
# SVG ID for frame7
frame7=star7
# Frame animation delay in [ms]
animation-delay=100



# The score board input icons player 0
[scoreinput0]
# Width of the item  [0..1]
width=0.050
# Item positions relativ to score widget itself [0..1,0..1]
pos=0.04,0.02
# Z-Value 
zValue=120.0
# SVG ID of the image: Auto means to read read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=3
# SVG ID for frame0 (Mouse input)
frame0=score_mouse
# SVG ID for frame1 (Keyboard input)
frame1=score_key
# SVG ID for frame2 (AI input)
frame2=score_ai
# SVG ID for frame3 (Network input)
frame3=score_network



# The score board input icons player 1
[scoreinput1]
# Width of the item [0..1]
width=0.050
# Item positions relativ to score widget itself [0..1,0..1]
pos=0.20,0.02
# Z-Value 
zValue=120.0
# SVG ID of the image: Auto means to read read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=3
# SVG ID for frame0 (Mouse input)
frame0=score_mouse
# SVG ID for frame1 (Keyboard input)
frame1=score_key
# SVG ID for frame2 (AI input)
frame2=score_ai
# SVG ID for frame3 (Network input)
frame3=score_network



# The score board next to the game board
[scoreboard]
# Width of the item [0..1]
width=0.28
# Item position [0..1,0..1]
pos=0.60,0.133
# Z-Value 
zValue=100.0
# SVG ID
svgid=score

# Sub-item positions relativ to score widget itself (status texts player 0 and 1)
posWon0=0.20,0.33
posDraw0=0.20,0.44
posLoss0=0.20,0.55
posBreak0=0.20,0.66
posName0=0.08,0.78
posWon1=0.75,0.33
posDraw1=0.75,0.44
posLoss1=0.75,0.55
posBreak1=0.75,0.66
posName1=0.62,0.78
#posAI=0.35,0.90
# Font width and height relativ to score widget size!!!
fontHeight=0.067
fontWidth=0.375
# Font color for name of player 0 and 1. The current player's name is colored with 'active'
fontColorActive=255,255,255
fontColorPlayer0=0,0,0
fontColorPlayer1=255,0,0



# The game board (frame)
[board]
# Width of the item [0..1]
width=0.44
# Item position [0..1,0..1]
pos=0.0968,0.101
# Z-Value 
zValue=150.0
# SVG ID
svgid=board


# The back of the game board 
[boardback]
# Width of the item [0..1]
width=0.438
# Item position [0..1,0..1]
pos=0.0968,0.101
# Z-Value 
zValue=1.0
# SVG ID
svgid=boardback


# # The game over message
# [gameover]
# # Item position [0..1,0..1]
# pos=0.62,0.19
# # Width of the item [0..1]
# width=0.30
# # Z-Value 
# zValue=300.0
# # SVG ID
# svgid=gameover


# The game board (frame) used in the intro
[introboard]
# Width of the item [0..1]
width=0.442424242
# Item position [0..1,0..1]
pos=0.4300,0.190
# Z-Value 
zValue=150.0
# SVG ID
svgid=board


# The quicklaunch field in the intro
[quicklaunch]
# Width of the item [0..1]
width=0.30       
# Item position [0..1,0..1]
pos=0.0500,0.0500
# Z-Value 
zValue=150.0
# SVG ID
svgid=quicklaunch

# Position of text
posQuickstart=0.025,0.0025
posStartplayer=0.05,0.145
posColor=0.05,0.26
# Font for text quickstart
fontHeightHeader=0.070
textHeightHeader=0.080
textWidthHeader=0.95
fontColorHeader=255,255,255
# Font and available space for other text 
fontHeight=0.050
fontColor=0,0,0
textWidth=0.55
textHeight=0.10


# The 'black' start button
[button0_start]
# Width of the item [0..1]
width=0.040
# Item position [0..1,0..1]
pos=0.230,0.135
# Z-Value 
zValue=200.0
# SVG ID of the image: Auto means to read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=3
# SVG ID for frame0
frame0=piece0
frame1=piece0_hover
frame2=piece0_on
frame3=piece0_on_hover

# The 'red' start button
[button1_start]
# Width of the item [0..1]
width=0.040
# Item position [0..1,0..1]
pos=0.275,0.135
# Z-Value 
zValue=200.0
# SVG ID of the image: Auto means to read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=3
# SVG ID for frame0
frame0=piece1
frame1=piece1_hover
frame2=piece1_on
frame3=piece1_on_hover

# The 'black' color choice button
[button0_color]
# Width of the item [0..1]
width=0.040
# Item position [0..1,0..1]
pos=0.230,0.19
# Z-Value 
zValue=200.0
# SVG ID of the image: Auto means to read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=3
# SVG ID for frame0
frame0=piece0
frame1=piece0_hover
frame2=piece0_on
frame3=piece0_on_hover

# The 'red' color choice button
[button1_color]
# Width of the item [0..1]
width=0.040
# Item position [0..1,0..1]
pos=0.275,0.19 
# Z-Value 
zValue=200.0
# SVG ID of the image: Auto means to read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=3
# SVG ID for frame0
frame0=piece1
frame1=piece1_hover
frame2=piece1_on
frame3=piece1_on_hover

# The 'start_ai_easy' button
[button_aieasy]
# Width of the item [0..1]
width=0.19
# Item position [0..1,0..1]
pos=0.100,0.29
# Z-Value 
zValue=200.0
# SVG ID of the image: Auto means to read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=2
# SVG ID for frame0
frame0=button_off
frame1=button_off_hover
frame2=button_on
# Font color, width and height relativ to button size!!!
fontHeight=0.30
textWidth=0.90
textHeight=0.90
fontColor=0,0,0

# The 'start_ai_normal' button
[button_ainormal]
# Width of the item [0..1]
width=0.19
# Item position [0..1,0..1]
pos=0.100,0.35
# Z-Value 
zValue=200.0
# SVG ID of the image: Auto means to read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=2
# SVG ID for frame0
frame0=button_off
frame1=button_off_hover
frame2=button_on
# Font color, width and height relativ to button size!!!
fontHeight=0.30
textWidth=0.90
textHeight=0.90
fontColor=0,0,0

# The 'start_ai_hard' button
[button_aihard]
# Width of the item [0..1]
width=0.19
# Item position [0..1,0..1]
pos=0.100,0.41
# Z-Value 
zValue=200.0
# SVG ID of the image: Auto means to read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=2
# SVG ID for frame0
frame0=button_off
frame1=button_off_hover
frame2=button_on
# Font color, width and height relativ to button size!!!
fontHeight=0.30
textWidth=0.90
textHeight=0.90
fontColor=0,0,0

# The 'start_player' button
[button_player]
# Width of the item [0..1]
width=0.19
# Item position [0..1,0..1]
pos=0.100,0.47
# Z-Value 
zValue=200.0
# SVG ID of the image: Auto means to read ID from frameX (below)
svgid=auto
# First frame number to read
start-frame=0
# Last frame number to read
end-frame=2
# SVG ID for frame0
frame0=button_off
frame1=button_off_hover
frame2=button_on
# Font color, width and height relativ to button size!!!
fontHeight=0.30
textWidth=0.90
textHeight=0.90
fontColor=0,0,0
